@@ -2,11 +2,11 @@
 	/* GERBVIEW - Gestion des Options et Reglages */
 	/********************************************/
 
-	/*	 Fichier options.cpp 	*/
+	/*	 File options.cpp 	*/
 
 /*
- Affichage et modifications des parametres de travail Gerbview
-*/
+ * Set the display options for Gerbview
+ */
 
 
 #include "fctsys.h"
@@ -20,45 +20,42 @@
 #include "protos.h"
 #include <wx/spinctrl.h>
 
-/* Fonctions locales */
-
-/* variables locales */
 
 /*****************************************************************/
 void WinEDA_GerberFrame::OnSelectOptionToolbar(wxCommandEvent& event)
 /*****************************************************************/
+/** Function OnSelectOptionToolbar
+ *  called to validate current choices
+ */
 {
 int id = event.GetId();
-wxClientDC dc(DrawPanel);
 
-	DrawPanel->PrepareGraphicContext(&dc);
 	switch ( id )
 	{
 		case ID_TB_OPTIONS_SHOW_GRID:
 			m_Draw_Grid = g_ShowGrid = m_OptionsToolBar->GetToolState(id);
-			DrawPanel->ReDraw(&dc, TRUE);
+			DrawPanel->Refresh(TRUE);
 			break;
 
 		case ID_TB_OPTIONS_SELECT_UNIT_MM:
 			g_UnitMetric = MILLIMETRE;
-			Affiche_Status_Box();	 /* Reaffichage des coord curseur */
+			Affiche_Status_Box();
 			break;
 
 		case ID_TB_OPTIONS_SELECT_UNIT_INCH:
 			g_UnitMetric = INCHES;
-			Affiche_Status_Box();	 /* Reaffichage des coord curseur */
+			Affiche_Status_Box();
 			break;
 
 		case ID_TB_OPTIONS_SHOW_POLAR_COORD:
 			Affiche_Message(wxEmptyString);
 			DisplayOpt.DisplayPolarCood = m_OptionsToolBar->GetToolState(id);
-			Affiche_Status_Box();	 /* Reaffichage des coord curseur */
+			Affiche_Status_Box();
 			break;
 
 		case ID_TB_OPTIONS_SELECT_CURSOR:
-			DrawPanel->CursorOff(&dc);
 			g_CursorShape = m_OptionsToolBar->GetToolState(id);
-			DrawPanel->CursorOn(&dc);
+			DrawPanel->Refresh(TRUE);
 			break;
 
 		case ID_TB_OPTIONS_SHOW_PADS_SKETCH:
@@ -72,7 +69,7 @@ wxClientDC dc(DrawPanel);
 				m_DisplayPadFill = TRUE;
 				DisplayOpt.DisplayPadFill = TRUE;
 			}
-			DrawPanel->ReDraw(&dc, TRUE);
+			DrawPanel->Refresh(TRUE);
 			break;
 
 		case ID_TB_OPTIONS_SHOW_TRACKS_SKETCH:
@@ -86,15 +83,21 @@ wxClientDC dc(DrawPanel);
 				m_DisplayPcbTrackFill = TRUE;
 				DisplayOpt.DisplayPcbTrackFill = TRUE;
 			}
-			DrawPanel->ReDraw(&dc, TRUE);
+			DrawPanel->Refresh(TRUE);
+			break;
+
+		case ID_TB_OPTIONS_SHOW_POLYGONS_SKETCH:
+			if ( m_OptionsToolBar->GetToolState(id) )	// Polygons filled asked
+				 g_DisplayPolygonsModeSketch = 1;
+			else g_DisplayPolygonsModeSketch = 0;
+			DrawPanel->Refresh(TRUE);
 			break;
 
 		case ID_TB_OPTIONS_SHOW_DCODES:
 			DisplayOpt.DisplayPadNum = m_OptionsToolBar->GetToolState(id);
-			DrawPanel->ReDraw(&dc, TRUE);
+			DrawPanel->Refresh(TRUE);
 			break;
 
-
 		default:
 			DisplayError(this, wxT("WinEDA_PcbFrame::OnSelectOptionToolbar error"));
 			break;
@@ -104,16 +107,9 @@ wxClientDC dc(DrawPanel);
 }
 
 
-enum id_optpcb
-{
-	ID_ACCEPT_OPT = 1000,
-	ID_CANCEL_OPT
-};
-	/*************************************************/
-	/* classe derivee pour la frame de Configuration */
-	/*************************************************/
-
+/******************************************************/
 class WinEDA_GerberGeneralOptionsFrame: public wxDialog
+/******************************************************/
 {
 private:
 
@@ -123,38 +119,36 @@ private:
 	wxRadioBox * m_CursorShape;
 	wxRadioBox * m_GerberDefaultScale;
 
-
-
 	// Constructor and destructor
 public:
 	WinEDA_GerberGeneralOptionsFrame(WinEDA_BasePcbFrame *parent,const wxPoint& pos);
-	~WinEDA_GerberGeneralOptionsFrame(void) {};
+	~WinEDA_GerberGeneralOptionsFrame() {};
 
 private:
-	void AcceptPcbOptions(wxCommandEvent& event);
-	void OnQuit(wxCommandEvent & event);
+	void OnOkClick(wxCommandEvent& event);
+	void OnCancelClick(wxCommandEvent & event);
 
 	DECLARE_EVENT_TABLE()
 
 };
-/* Construction de la table des evenements pour WinEDA_GerberGeneralOptionsFrame */
+/* Events table for WinEDA_GerberGeneralOptionsFrame */
 BEGIN_EVENT_TABLE(WinEDA_GerberGeneralOptionsFrame, wxDialog)
-	EVT_BUTTON(ID_ACCEPT_OPT, WinEDA_GerberGeneralOptionsFrame::AcceptPcbOptions)
-	EVT_BUTTON(ID_CANCEL_OPT, WinEDA_GerberGeneralOptionsFrame::OnQuit)
+	EVT_BUTTON(wxID_OK, WinEDA_GerberGeneralOptionsFrame::OnOkClick)
+	EVT_BUTTON(wxID_CANCEL, WinEDA_GerberGeneralOptionsFrame::OnCancelClick)
 END_EVENT_TABLE()
 
 
 
 
-	/*************************************************/
-	/* Constructeur de WinEDA_GerberGeneralOptionsFrame */
-	/************************************************/
-
+/**********************************************************************************************/
 WinEDA_GerberGeneralOptionsFrame::WinEDA_GerberGeneralOptionsFrame(WinEDA_BasePcbFrame *parent,
 		const wxPoint& framepos):
 		wxDialog(parent, -1, _("Gerbview Options"),
 				 framepos, wxSize(300, 240),
 				wxDEFAULT_DIALOG_STYLE|wxFRAME_FLOAT_ON_PARENT )
+/**********************************************************************************************/
+/** WinEDA_GerberGeneralOptionsFrame Constructor
+*/
 {
 	m_Parent = parent;
 	SetFont(*g_DialogFont);
@@ -168,15 +162,15 @@ WinEDA_GerberGeneralOptionsFrame::WinEDA_GerberGeneralOptionsFrame(WinEDA_BasePc
 	MainBoxSizer->Add(MiddleBoxSizer, 0, wxGROW|wxALL, 5);
 	MainBoxSizer->Add(RightBoxSizer, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
 
-	wxButton * Button = new wxButton(this, ID_ACCEPT_OPT, _("Accept"));
+	wxButton * Button = new wxButton(this, wxID_OK, _("OK"));
 	Button->SetForegroundColour(*wxRED);
 	RightBoxSizer->Add(Button, 0, wxGROW|wxALL, 5);
 
-	Button = new wxButton(this, ID_CANCEL_OPT, _("Cancel"));
+	Button = new wxButton(this, wxID_CANCEL, _("Cancel"));
 	Button->SetForegroundColour(*wxBLUE);
 	RightBoxSizer->Add(Button, 0, wxGROW|wxALL, 5);
 
-	/* Display Selection affichage des coordonnes polaires */
+	/* Display / not display polar coordinates: */
 wxString list_coord[2] =
 	{ _("No Display"),
 	_("Display") };
@@ -186,7 +180,7 @@ wxString list_coord[2] =
 	m_PolarDisplay->SetSelection(DisplayOpt.DisplayPolarCood ? 1 : 0);
 	LeftBoxSizer->Add(m_PolarDisplay, 0, wxGROW|wxALL, 5);
 
-	/* Selection choix des units d'affichage */
+	/* Selection of units */
 wxString list_units[2] = {
 	_("Inches"),
 	_("millimeters") };
@@ -195,7 +189,7 @@ wxString list_units[2] = {
 	m_BoxUnits->SetSelection( g_UnitMetric ? 1 : 0);
 	LeftBoxSizer->Add(m_BoxUnits, 0, wxGROW|wxALL, 5);
 
-	/* Selection forme du curseur */
+	/* Selection of cursor shape */
 wxString list_cursors[2] = { _("Small"), _("Big") };
 	m_CursorShape = new wxRadioBox(this, -1, _("Cursor"), wxDefaultPosition, wxDefaultSize,
 					2, list_cursors, 1);
@@ -210,71 +204,65 @@ wxString list_scales[2] = { _("format: 2.3"), _("format 3.4") };
 	m_GerberDefaultScale->SetSelection( (g_Default_GERBER_Format == 23) ? 0 : 1);
 	MiddleBoxSizer->Add(m_GerberDefaultScale, 0, wxGROW|wxALL, 5);
 
-
 	GetSizer()->Fit(this);
     GetSizer()->SetSizeHints(this);
 }
 
+
 /************************************************************************/
-void  WinEDA_GerberGeneralOptionsFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
+void  WinEDA_GerberGeneralOptionsFrame::OnCancelClick(wxCommandEvent& WXUNUSED(event))
 /************************************************************************/
 {
-    // true is to force the frame to close
-    Close(true);
+    EndModal( -1 );
 }
 
 
 
 /*****************************************************************************/
-void WinEDA_GerberGeneralOptionsFrame::AcceptPcbOptions(wxCommandEvent& event)
+void WinEDA_GerberGeneralOptionsFrame::OnOkClick(wxCommandEvent& event)
 /*****************************************************************************/
 {
 	DisplayOpt.DisplayPolarCood =
 		(m_PolarDisplay->GetSelection() == 0) ? FALSE : TRUE;
-	g_UnitMetric = (m_BoxUnits->GetSelection() == 0)  ? 0 : 1;
+	g_UnitMetric = (m_BoxUnits->GetSelection() == 0) ? 0 : 1;
 	g_CursorShape = m_CursorShape->GetSelection();
 	g_Default_GERBER_Format =
 		(m_GerberDefaultScale->GetSelection() == 0) ? 23 : 34;
 
-	EndModal(1);
+	EndModal( 1 );
 }
 
 
 
-/******************************************************************/
-/* classe derivee pour la frame de Configuration WinEDA_LookFrame */
-/******************************************************************/
-
+/*******************************************/
+/* Dialog frame to select deisplay options */
+/*******************************************/
 class WinEDA_LookFrame: public wxDialog
 {
 private:
-protected:
-public:
-
 	WinEDA_BasePcbFrame * m_Parent;
-
 	wxRadioBox * m_OptDisplayLines;
-
 	wxRadioBox * m_OptDisplayFlashes;
+	wxRadioBox * m_OptDisplayPolygons;
 	wxCheckBox * m_OptDisplayDCodes;
-
 	wxRadioBox * m_OptDisplayDrawings;
 
-
+public:
 	// Constructor and destructor
 	WinEDA_LookFrame(WinEDA_BasePcbFrame *parent,const wxPoint& pos);
-	~WinEDA_LookFrame(void) {};
+	~WinEDA_LookFrame() {};
 
-	void AcceptPcbOptions(wxCommandEvent& event);
-	void OnQuit(wxCommandEvent & event);
+private:
+	void OnOkClick(wxCommandEvent& event);
+	void OnCancelClick(wxCommandEvent & event);
 
 	DECLARE_EVENT_TABLE()
 
 };
 /* Construction de la table des evenements pour WinEDA_LookFrame */
 BEGIN_EVENT_TABLE(WinEDA_LookFrame, wxDialog)
-	EVT_BUTTON(ID_ACCEPT_OPT, WinEDA_LookFrame::AcceptPcbOptions)
-	EVT_BUTTON(ID_CANCEL_OPT, WinEDA_LookFrame::OnQuit)
+	EVT_BUTTON(wxID_OK, WinEDA_LookFrame::OnOkClick)
+	EVT_BUTTON(wxID_CANCEL, WinEDA_LookFrame::OnCancelClick)
 END_EVENT_TABLE()
 
 
@@ -298,11 +286,11 @@ WinEDA_LookFrame::WinEDA_LookFrame(WinEDA_BasePcbFrame *parent,
 	MainBoxSizer->Add(MiddleBoxSizer, 0, wxGROW|wxALL, 5);
 	MainBoxSizer->Add(RightBoxSizer, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
 
-	wxButton * Button = new wxButton(this, ID_ACCEPT_OPT, _("Accept"));
+	wxButton * Button = new wxButton(this, wxID_OK, _("OK"));
 	Button->SetForegroundColour(*wxRED);
 	RightBoxSizer->Add(Button, 0, wxGROW|wxALL, 5);
 
-	Button = new wxButton(this, ID_CANCEL_OPT, _("Cancel"));
+	Button = new wxButton(this, wxID_CANCEL, _("Cancel"));
 	Button->SetForegroundColour(*wxBLUE);
 	RightBoxSizer->Add(Button, 0, wxGROW|wxALL, 5);
 
@@ -311,15 +299,25 @@ wxString list_opt2[2] = { _("Sketch"), _("Filled") };
 	m_OptDisplayLines = new wxRadioBox(this, -1, _("Lines:"),
 				wxDefaultPosition, wxDefaultSize,
 				2, list_opt2, 1);
-	if ( DisplayOpt.DisplayPcbTrackFill ) m_OptDisplayLines->SetSelection(1);
+	if ( DisplayOpt.DisplayPcbTrackFill )
+		m_OptDisplayLines->SetSelection(1);
 	LeftBoxSizer->Add(m_OptDisplayLines, 0, wxGROW|wxALL, 5);
 
 	m_OptDisplayFlashes = new wxRadioBox(this, -1, _("Spots:"),
 				wxDefaultPosition, wxDefaultSize,
 				2, list_opt2, 1);
-	if ( DisplayOpt.DisplayPadFill ) m_OptDisplayFlashes->SetSelection(1);
+	if ( DisplayOpt.DisplayPadFill )
+		m_OptDisplayFlashes->SetSelection(1);
 	LeftBoxSizer->Add(m_OptDisplayFlashes, 0, wxGROW|wxALL, 5);
 
+		// Show Option Draw polygons
+	m_OptDisplayPolygons = new wxRadioBox(this, -1, _("Polygons:"),
+				wxDefaultPosition, wxDefaultSize,
+				2, list_opt2, 1);
+	if ( g_DisplayPolygonsModeSketch == 0)
+		m_OptDisplayPolygons->SetSelection(1);
+	LeftBoxSizer->Add(m_OptDisplayPolygons, 0, wxGROW|wxALL, 5);
+
 wxString list_opt3[3] = { _("Sketch"), _("Filled"), _("Line") };
 	m_OptDisplayDrawings = new wxRadioBox(this, -1, _("Display other items:"),
 				wxDefaultPosition, wxDefaultSize,
@@ -327,8 +325,9 @@ wxString list_opt3[3] = { _("Sketch"), _("Filled"), _("Line") };
 	m_OptDisplayDrawings->SetSelection(DisplayOpt.DisplayDrawItems);
 	MiddleBoxSizer->Add(m_OptDisplayDrawings, 0, wxGROW|wxALL, 5);
 
-	m_OptDisplayDCodes = new wxCheckBox(this, -1, _("Show D-Codes"));
-	if ( DisplayOpt.DisplayPadNum ) m_OptDisplayDCodes->SetValue(TRUE);
+	m_OptDisplayDCodes = new wxCheckBox(this, -1, _("Show D codes"));
+	if ( DisplayOpt.DisplayPadNum )
+		m_OptDisplayDCodes->SetValue(TRUE);
 	MiddleBoxSizer->Add(m_OptDisplayDCodes, 0, wxGROW|wxALL, 5);
  
 	GetSizer()->Fit(this);
@@ -337,27 +336,33 @@ wxString list_opt3[3] = { _("Sketch"), _("Filled"), _("Line") };
 
 
 /**************************************************************/
-void  WinEDA_LookFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
+void  WinEDA_LookFrame::OnCancelClick(wxCommandEvent& WXUNUSED(event))
 /**************************************************************/
 {
-    // true is to force the frame to close
-    Close(true);
+    EndModal( -1 );
 }
 
 
 /*************************************************************/
-void WinEDA_LookFrame::AcceptPcbOptions(wxCommandEvent& event)
+void WinEDA_LookFrame::OnOkClick(wxCommandEvent& event)
 /*************************************************************/
 /* Met a jour les options
-*/
+ */
 {
-	if ( m_OptDisplayLines->GetSelection() == 1)
+	if ( m_OptDisplayLines->GetSelection() == 1 )
 		DisplayOpt.DisplayPcbTrackFill = TRUE;
-	else DisplayOpt.DisplayPcbTrackFill = FALSE;
+	else
+		DisplayOpt.DisplayPcbTrackFill = FALSE;
 
-	if (m_OptDisplayFlashes->GetSelection() == 1 )
+	if ( m_OptDisplayFlashes->GetSelection() == 1 )
 		 DisplayOpt.DisplayPadFill = TRUE;
-	else DisplayOpt.DisplayPadFill = FALSE;
+	else
+		DisplayOpt.DisplayPadFill = FALSE;
+
+	if ( m_OptDisplayPolygons->GetSelection() == 0 )
+		 g_DisplayPolygonsModeSketch = 1;
+	else
+		g_DisplayPolygonsModeSketch = 0;
 
 	DisplayOpt.DisplayPadNum = m_OptDisplayDCodes->GetValue();
 
@@ -368,7 +373,7 @@ void WinEDA_LookFrame::AcceptPcbOptions(wxCommandEvent& event)
 
 	m_Parent->GetScreen()->SetRefreshReq();
 
-	EndModal(1);
+	EndModal( 1 );
 }
 
 
@@ -379,25 +384,24 @@ void WinEDA_LookFrame::AcceptPcbOptions(wxCommandEvent& event)
 void WinEDA_GerberFrame::InstallPcbOptionsFrame(const wxPoint & pos, int id)
 /***************************************************************************/
 {
-
 	switch ( id )
-		{
+	{
 		case ID_PCB_LOOK_SETUP:
-			{
+		{
 			WinEDA_LookFrame * OptionsFrame =
 				new WinEDA_LookFrame(this, pos);
-			OptionsFrame->ShowModal(); OptionsFrame->Destroy();
-			}
+			OptionsFrame->ShowModal();
+			OptionsFrame->Destroy();
+		}
 			break;
 
 		case ID_OPTIONS_SETUP:
-			{
+		{
 			WinEDA_GerberGeneralOptionsFrame * OptionsFrame =
 				new WinEDA_GerberGeneralOptionsFrame(this, pos);
-			OptionsFrame->ShowModal(); OptionsFrame->Destroy();
-			}
-			break;
+			OptionsFrame->ShowModal();
+			OptionsFrame->Destroy();
 		}
+			break;
+	}
 }
-
-
