@@ -2,6 +2,8 @@
 #ifndef ID_H
 #define ID_H
 
+#define MAX_ITEMS_IN_PICKER     15  ///< max no. items in the popup menu for item selection
+
 enum main_id {
 	ID_MAIN_FRAME = 100,
 	ID_LEFT_FRAME,
@@ -12,17 +14,17 @@ enum main_id {
 	ID_PROJECT_TREE_REFRESH,
 	ID_PROJECT_RUNPY,
 	ID_PROJECT_NEWFILE,
-	ID_PROJECT_NEWSCH,
-	ID_PROJECT_NEWBRD,
+	ID_PROJECT_UNUSED0,
+	ID_PROJECT_UNUSED1,
 	ID_PROJECT_NEWPY,
-	ID_PROJECT_NEWGERBER,
+	ID_PROJECT_UNUSED2,
 	ID_PROJECT_NEWTXT,
-	ID_PROJECT_NEWNET,
+	ID_PROJECT_UNUSED3,
 	ID_PROJECT_NEWDIR,
 	ID_PROJECT_DELETE,
 	ID_PROJECT_RENAME,
-	ID_PROJECT_UNUSED0,
-	ID_PROJECT_UNUSED1,
+	ID_PROJECT_OPEN_FILE_WITH_TEXT_EDITOR,
+	ID_PROJECT_UNUSED4,
 
 	ID_MAIN_COMMAND,
 	ID_TO_EDITOR,
@@ -61,9 +63,19 @@ enum main_id {
 	ID_SAVE_ONE_SHEET,
 	ID_SAVE_ONE_SHEET_AS,
 
+	ID_CONFIG_AND_PREFERENCES_START,
 	ID_CONFIG_REQ,
 	ID_CONFIG_SAVE,
 	ID_CONFIG_READ,
+	ID_PREFERENCES_CREATE_CONFIG_HOTKEYS,
+	ID_PREFERENCES_READ_CONFIG_HOTKEYS,
+	ID_PREFERENCES_EDIT_CONFIG_HOTKEYS,
+	ID_PREFERENCES_HOTKEY_PATH_IS_HOME,
+	ID_PREFERENCES_HOTKEY_PATH_IS_KICAD,
+	ID_PREFERENCES_HOTKEY_SHOW_CURRENT_LIST,
+	ID_PREFERENCES_UNUSED2,
+	ID_PREFERENCES_UNUSED3,
+	ID_CONFIG_AND_PREFERENCES_END,
 
 	ID_GEN_PRINT,
 	ID_GEN_PLOT,
@@ -93,11 +105,11 @@ enum main_id {
 	ID_PREFERENCES_FONT_INFOSCREEN,
 	ID_PREFERENCES_FONT_DIALOG,
 	ID_PREFERENCES_FONT_STATUS,
-	ID_PREFERENCES_UNUSED3,
-	ID_PREFERENCES_UNUSED4,
-	ID_PREFERENCES_UNUSED5,
-	ID_PREFERENCES_UNUSED6,
-	ID_PREFERENCES_UNUSED7,
+	ID_PREFERENCES_FONT_UNUSED3,
+	ID_PREFERENCES_FONT_UNUSED4,
+	ID_PREFERENCES_FONT_UNUSED5,
+	ID_PREFERENCES_FONT_UNUSED6,
+	ID_PREFERENCES_FONT_UNUSED7,
 	ID_PREFERENCES_FONT_END,
 
 	// Find id menu
@@ -135,7 +147,7 @@ enum main_id {
 	ID_LANGUAGE_HUNGARIAN,
 	ID_LANGUAGE_POLISH,
 	ID_LANGUAGE_KOREAN,
-	ID_LANGUAGE_UNUSED2,
+	ID_LANGUAGE_CATALAN,
 	ID_LANGUAGE_UNUSED3,
 	ID_LANGUAGE_UNUSED4,
 	ID_LANGUAGE_CHOICE_END,
@@ -270,7 +282,7 @@ enum main_id {
 	ID_POPUP_SCH_DELETE_NODE,
 	ID_POPUP_SCH_MOVE_CMP_REQUEST,
 	ID_POPUP_SCH_DELETE_CMP,
-	ID_POPUP_SCH_UNUSED_0,
+	ID_POPUP_SCH_DRAG_CMP_REQUEST,
 	ID_POPUP_SCH_UNUSED_1,
 	ID_POPUP_SCH_UNUSED_2,
 	ID_POPUP_SCH_ENTRY_SELECT_SLASH,
@@ -629,6 +641,10 @@ enum main_id {
 
 	ID_POPUP_PCB_END_RANGE,
 
+    // reserve a block of MAX_ITEMS_IN_PICKER ids for the item selection popup  
+    ID_POPUP_PCB_ITEM_SELECTION_START,
+    ID_POPUP_PCB_ITEM_SELECTION_END = MAX_ITEMS_IN_PICKER + ID_POPUP_PCB_ITEM_SELECTION_START,
+
 	ID_POPUP_PCB_AUTOPLACE_START_RANGE,
 
 	ID_POPUP_PCB_AUTOPLACE_FIXE_MODULE,
@@ -698,7 +714,7 @@ enum main_id {
 
 	ID_AUX_TOOLBAR_PCB_VIA_SIZE,
 	ID_AUX_TOOLBAR_PCB_TRACK_WIDTH,
-	ID_AUX_TOOLBAR_PCB_UNUSED1,
+	ID_AUX_TOOLBAR_PCB_SELECT_LAYER_PAIR,
 	ID_AUX_TOOLBAR_PCB_UNUSED2,
 	ID_AUX_TOOLBAR_PCB_UNUSED3,
 	ID_AUX_TOOLBAR_PCB_UNUSED4,
@@ -738,7 +754,8 @@ enum main_id {
 	ID_MODEDIT_DELETE_ITEM_BUTT,
 	ID_MODEDIT_PAD_SETTINGS,
 	ID_MODEDIT_LOAD_MODULE_FROM_BOARD,
-	ID_MODEDIT_SAVE_MODULE_IN_BOARD,
+	ID_MODEDIT_INSERT_MODULE_IN_BOARD,
+	ID_MODEDIT_UPDATE_MODULE_IN_BOARD,
 	ID_MODEDIT_EDIT_MODULE_PROPERTIES,
 	ID_MODEDIT_TRANSFORM_MODULE,
 	ID_MODEDIT_MODULE_ROTATE,
@@ -797,7 +814,7 @@ enum main_id {
 	ID_TB_OPTIONS_SHOW_DCODES,
 	ID_TB_OPTIONS_SHOW_HIGHT_CONTRAST_MODE,
 	ID_TB_OPTIONS_SHOW_EXTRA_VERTICAL_TOOLBAR1,
-	ID_TB_OPTIONS_UNUSED5,
+	ID_TB_OPTIONS_SHOW_POLYGONS_SKETCH,
 	ID_TB_OPTIONS_UNUSED6,
 	ID_TB_OPTIONS_UNUSED7,
 	ID_TB_OPTIONS_UNUSED8,
@@ -851,7 +868,6 @@ enum main_id {
 	ID_PCB_MUWAVE_END_CMD,
 
 	ID_END_LIST
-
 };
 
 #endif	/* define ID_H */
