@@ -29,14 +29,14 @@ static struct PcbQueue *Tail = NULL;
 static struct PcbQueue *Save = NULL;	/* hold empty queue structs */
 
 /* Routines definies ici : */
-void InitQueue( void );
+void InitQueue();
 void GetQueue( int *, int *, int *, int *, int * );
 int SetQueue( int, int, int, int, int, int, int );
 void ReSetQueue( int, int, int, int, int, int, int );
 
 
 /************************/
-void FreeQueue(void)
+void FreeQueue()
 /************************/
 /* Free the memory used for storing all the queue */
 {
@@ -49,11 +49,11 @@ struct PcbQueue *p;
 		}
 }
 	/************************/
-	/* void InitQueue(void) */
+	/* void InitQueue() */
 	/************************/
 
 /* initialize the search queue */
-void InitQueue(void)
+void InitQueue()
 {
 struct PcbQueue *p;
 
