@@ -1,6 +1,6 @@
 		/****************************************************/
-		/* Affichage du panneau d'information (copyright..) */
-		/* Commun a CVPCB, EESCHEMA et PCBNEW				*/
+		/* Display a generic info about kikac (copyright..) */
+		/* Common tp CVPCB, EESCHEMA, PCBNEW and GERBVIEW	*/
 		/****************************************************/
 
 #include "fctsys.h"
@@ -14,34 +14,35 @@
 // Import:
 extern wxString g_Main_Title;
 
-wxString MsgInfos(
+// Local
 #ifdef GERBVIEW
-wxT("** GERBVIEW  (jul 2001 .. 2006) **")
+static wxString MsgInfos(wxT("** GERBVIEW  (jul 2001 .. 2007) **"));
 #else
 #ifdef PCBNEW
-wxT("** PCBNEW  (sept 1992 .. 2006) **")
+static wxString MsgInfos(wxT("** PCBNEW  (sept 1992 .. 2007) **"));
 #endif
 #endif
 
 #ifdef CVPCB
-wxT("** CVPCB  (sept 1992 .. 2006) **")
+static wxString MsgInfos(wxT("** CVPCB  (sept 1992 .. 2007) **"));
 #endif
 
 #ifdef KICAD
-wxT("** KICAD (jul 2000 .. 2006) **")
+static wxString MsgInfos(wxT("** KICAD  (jul 2000 .. 2007) **"));
 #endif
 
 #ifdef EESCHEMA
-wxT("** EESCHEMA  (sept 1994 .. 2006) **")
+static wxString MsgInfos(wxT("** EESCHEMA  (sept 1994 .. 2007) **"));
 #endif
-);
 
-/* Routines Locales */
+// Routines Locales
 
 /*******************************************/
 void Print_Kicad_Infos(wxWindow * frame)
 /*******************************************/
 {
+wxString AboutCaption = wxT("About ");
+
 wxString Msg = MsgInfos;
 	Msg << wxT("\n\n") << _("Build Version:") << wxT("\n") ;
 
@@ -51,7 +52,7 @@ wxString Msg = MsgInfos;
 #else
 	Msg << wxT(" - Ansi version");
 #endif
-	
+
 #ifdef KICAD_PYTHON
 	Msg << wxT("\n");
 	Msg << wxT( "python : " );
@@ -59,16 +60,20 @@ wxString Msg = MsgInfos;
 #endif
 
 	Msg << wxT("\n\n") << _("Author:");
-	Msg << wxT("JP CHARRAS\n\n") << _("Based on wxWidgets ");
+	Msg << wxT(" JP CHARRAS\n\n") << _("Based on wxWidgets ");
 	Msg << wxMAJOR_VERSION << wxT(".") <<
 		wxMINOR_VERSION << wxT(".") << wxRELEASE_NUMBER;
-	if ( wxSUBRELEASE_NUMBER )
+	if( wxSUBRELEASE_NUMBER )
 		Msg << wxT(".") << wxSUBRELEASE_NUMBER;
 	Msg << _("\n\nGPL License");
-	Msg << _("\n\nWeb sites:\n");
+	Msg << _("\n\nAuthor's sites:\n");
 	Msg << wxT("http://iut-tice.ujf-grenoble.fr/kicad/\n");
 	Msg << wxT("http://www.gipsa-lab.inpg.fr/realise_au_lis/kicad/");
+	Msg << _("\n\nInternational wiki:\n");
+	Msg << wxT("http://kicad.sourceforge.net/\n");
 
-	wxMessageBox(Msg, wxEmptyString, wxICON_INFORMATION, frame);
+	AboutCaption << g_Main_Title << wxT(" ") << GetBuildVersion();
+
+	wxMessageBox(Msg, AboutCaption, wxICON_INFORMATION, frame);
 }
 
